% Ostwald Ripening

clc;clear;
format long g;

% Parameter Initialization - from 1.10.2

G = 4e-3;
mu = [1e-3, 1e-3];
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;

% Initial condition
x0 = [0.025; 0.05];

% constants of concentration
c1 = c0 + mu*x0.^3;

% Right side of ODE
f = @(t,x)  [k*(c1 - mu*x.^3 - cs*exp(G/x(1)));
    k*(c1 - mu*x.^3 - cs*exp(G/x(2)))];


% Time span
tSpan = [0 1e-1];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0); %ode15s

plot(tOut, xOut)

format long e
ind = find(xOut(:,1) > 0);
tau1 = tOut(ind(end))
L1 = xOut(ind(end),2)

%%
clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
mu = [1e-3, 1e-3];
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;

% Initial condition
x0 = [0.0975/2; 0.0975];

% constants of concentration
c1 = c0 + mu*x0.^3;

% Right side of ODE
f = @(t,x)  [k*(c1 - mu*x.^3 - cs*exp(G/x(1)));
    k*(c1 - mu*x.^3 - cs*exp(G/x(2)))];


% Time span
tSpan = [0 5];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0); %ode15s

plot(tOut, xOut)

format long e

ind = find(xOut(:,1) > 0);
tau2 = tOut(ind(end))
L2 = xOut(ind(end),2)
%%
clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
mu = [1e-3, 1e-3];
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e2/mu(1);

% Initial condition
x0 = [0.04; 0.08];

% constants of concentration
c1 = c0 + mu*x0.^3;

% Right side of ODE
f = @(t,x)  [k*(c1 - mu*x.^3 - cs*exp(G/x(1)));
    k*(c1 - mu*x.^3 - cs*exp(G/x(2)))];


% Time span
tSpan = [0 5];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0); %ode15s

plot(tOut, xOut)

format long e

ind = find(xOut(:,1) > 0);
tau3 = tOut(ind(end))
L3 = xOut(ind(end),2)