% Ostwald Ripening

clc;clear;
format long g;

% Parameter Initialization - from 1.10.2

G = 4e-3;
mu = [1e-3, 1e-3];
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;

% Initial condition
x0 = [0.025; 0.05];

% constants of concentration
c1 = c0 + mu*x0.^3;

% Right side of ODE
f = @(t,x)  [k*(c1 - mu*x.^3 - cs*exp(G/x(1)));
    k*(c1 - mu*x.^3 - cs*exp(G/x(2)))];


% Time span
tSpan = [0 5e-3];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0); %ode15s

plot(tOut, xOut)

format long e
ind = find(xOut(:,1) > 0);
tau1 = tOut(ind(end))
L1 = xOut(ind(end),2)

%Steady states
newc1 = c0 + mu(2)*L1^3;
g = @(x) mu(2)*x.^3 + cs*exp(G./x) - newc1;

xi1 = fzero(g, 0.025)
xi2 = fzero(g, 0.045)

if L1 > xi1
    c_infty1 = c1 - mu(2)*L1^3;
else
    c_infty1 = c1;
end
c_infty1
    

%%
clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
mu = [1e-3, 1e-3];
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;

% Initial condition
x0 = [0.0975/2; 0.0975];

% constants of concentration
c1 = c0 + mu*x0.^3;

% Right side of ODE
f = @(t,x)  [k*(c1 - mu*x.^3 - cs*exp(G/x(1)));
    k*(c1 - mu*x.^3 - cs*exp(G/x(2)))];


% Time span
tSpan = [0 1];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0); %ode15s

plot(tOut, xOut)

format long e

ind = find(xOut(:,1) > 0);
tau2 = tOut(ind(end))
L2 = xOut(ind(end),2)

%Steady states
newc1 = c0 + mu(2)*L2^3;
g = @(x) mu(2)*x.^3 + cs*exp(G./x) - newc1;

xi1 = fzero(g, 0.005)
xi2 = fzero(g, 1)

if L2 > xi1
    c_infty2 = c1 - mu(2)*L2^3;
else
    c_infty2 = c1;
end
c_infty2
    

%%
clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
mu = [1e-3, 1e-3];
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e2/mu(1);

% Initial condition
x0 = [0.04; 0.08];

% constants of concentration
c1 = c0 + mu*x0.^3;

% Right side of ODE
f = @(t,x)  [k*(c1 - mu*x.^3 - cs*exp(G/x(1)));
    k*(c1 - mu*x.^3 - cs*exp(G/x(2)))];


% Time span
tSpan = [0 2];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0); %ode15s

plot(tOut, xOut)

format long e

ind = find(xOut(:,1) > 0);
tau3 = tOut(ind(end))
L3 = xOut(ind(end),2)

%Steady states
newc1 = c0 + mu(2)*L3^3;
g = @(x) mu(2)*x.^3 + cs*exp(G./x) - newc1;

y = 0.005:0.001:0.12;
plot(y,g(y))

xi1 = fzero(g, 2e-2)
xi2 = fzero(g, 8e-2)

if L3 > xi1
    c_infty3 = c1 - mu(2)*L3^3;
else
    c_infty3 = c1;
end
c_infty3
    
