% 4CM - Latent Model with Logistic growth
clc;clear;

% Parameter Initialization
s = 10;
r = 0.03;
Tmax = 1500;
mu = 0.02;
alpha = 2.4;
beta = 0.24;
k1 = 2.4e-5;
k2 = 3e-3;
N = 1400;

%Non-infective equilibrium T-cell count
p = r - mu;
T0 = (Tmax/(2*r))* (p + sqrt(p^2 + 4*s*(r/Tmax)));

eps = 0.7;% eps_crit = 0.4494

k1 = k1*(1-eps);

R = k1*k2*N*T0/((k2+mu)*(alpha+k1*T0))

% Let y = [(1) Uninfected T-cell count; 
%          (2) Latently Infected T-cell count;
%          (3) Actively Infected T-cell count; 
%          (4) Virion count];

% Initial condition, time span
y0 = [1e3; 0; 0; 1e-3];
tSpan = [0 365*20];

        
% Differential Equation
dy = @(t,y) [s + r*y(1)*(1 - ((y(1)+y(2)+y(3))/Tmax))- mu*y(1) - k1*y(1)*y(4);
            k1*y(1)*y(4) - mu*y(2) - k2*y(2);
            k2*y(2) - beta*y(3);
            N*beta*y(3) - k1*y(1)*y(4) - alpha*y(4)];
   
% Solve ODE
[tOut yOut] = ode15s(dy, tSpan, y0);
        

fig1=figure('Color',[1 1 1]);
set(fig1,'defaulttextinterpreter','latex');
tOutYr = tOut/365;
plot(tOutYr, yOut(:,1),  tOutYr, yOut(:,4),'-.r');

legend('T(t)', 'V(t)');
xlabel('Time (yrs)');
ylabel('Population (cells/mm$^3$)');
title('$\epsilon = 0.7$')