clear; clc;

dx = 5e-2;
dt = 1e-2; %1e-2;
sigma = dt/(dx^2);
u0 = 2;

a = 0;
b = 10;

t0 = 4;
t = 0:dt:t0;

x = a:dx:b;
m = length(x);
n = t0/dt;

S(1,1:n+1) = 1;
S(2,1:n+1) = 0.5 + (t(1:n+1) >= 2);

M = (1+2*sigma)*diag(ones(m-2,1))-sigma*diag(ones(m-3,1),1)...
        -sigma*diag(ones(m-3,1),-1);
    
%Neumann BC at x = L
M(end, end) = M(end, end) - sigma;

[L,U] = lu(M);

for p = 1:2
    T(1,:) = [S(p,1);zeros(m-1, 1)];
    u(1,:) = u0*ones(m, 1);

    for i = 1:n
        %Control and Dirichlet BCs at x = 0
        T(i+1, 1) = S(p,i+1); 
        u(i+1, 1) = u0;
   
        NL = (u(i,1:m).*T(i,1:m))./(1 + T(i,1:m));
        
        %Implicit Solution for T
        b = T(i,2:m-1) + dt*NL(2:m-1);
        b(1) = b(1) + sigma*T(i+1, 1);
        
        y = L\b';
        T(i+1,2:m-1) = U\y;   
        
        %Neumann BC at x = L
        T(i+1, m) = T(i+1, m-1);
        
        %Explcit Solution for u
        for k = 1:m-1
            u(i+1, k+1) = u(i+1,k) - dx*u(i+1,k)*T(i+1,k)/(1 + T(i+1,k));
        end
    end
    J(p) = trapz(t,u(1:n+1, m));
    clear u;
    clear T;    
end
format long g
J
