% Ostwald Ripening

clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
mu = 1e-3;
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;

% Initial condition
x0 = 0.05;

% c1
c1 = c0 + mu*x0^3;

k*c1

% Find the Roots
g = @(x) mu*x.^3 + cs*exp(G./x) - c1;

% Plot function
%y = 0:0.001:0.05;
y = 0.02:0.001:0.06;
plot(y,g(y))

%%
format long e

xi1 = fzero(g, 0.025)
xi2 = fzero(g, 0.045)
%%

% Right side of ODE
f = @(t,x) k*(c1 - mu*x^3 - cs*exp(G/x));

% Time span
tSpan = [0 0.5];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0);

plot(tOut, xOut)
hold on
plot([0,tOut(end)], [xi1,xi1], '--g')
plot([0,tOut(end)], [xi2,xi2], '--r')
legend('L(t)', 'z_1', 'z_2')
