% Ostwald Ripening

clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
mu = 1e-3;
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;

% Initial condition
x0 = 5e-2;

% c1
c1 = c0 + mu*x0^3;

% Check constants
% Note that no semicolon causes output to the Command Window
% and the answer is stored in the variable 'ans'
k*c1 

% Find the Roots
g = @(x) c1 - (mu*x.^3 + cs*exp(G./x));

% Plot function

y = 0.01:0.001:0.06;
plot(y,g(y))

%%

%
format long e

xi1 = fzero(g, 0.025)

%

% Right side of ODE
f = @(t,x) k*(c1 - mu*x^3 - cs*exp(G/x));

% Time span
tSpan = [0 0.05];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0);

% Create new Figure window for new plot
figure;
plot(tOut, xOut)
hold on
plot([0,tOut(end)], [xi1,xi1], '--k')

legend('x(t)', 'z_1')
