% Ostwald Ripening

clc;clear;
format long g;

% Parameter Initialization

G = 4e-3;
cs = 7.52e-7;
c0 = 1.05*cs;
k = 5e7;
mu = 5e2/k;

% Initial condition
x0 = 8e-2;

% c1
c1 = c0 + mu*x0^3;

% Check constants
% Note that no semicolon causes output to the Command Window
% and the answer is stored in the variable 'ans'
k*c1 

% Find the Roots
g = @(x) c1 - (mu*x.^3 + cs*exp(G./x));

% Plot function

y = 0.01:0.001:0.16;
plot(y,g(y))
hold on
plot([0.01, 0.16], [0,0], 'k')

%%

%
format long e

xi1 = fzero(g, 0.06)

xi2 = fzero(g, 0.14)

%

% Right side of ODE
f = @(t,x) k*(c1 - mu*x^3 - cs*exp(G/x));

% Time span
tSpan = [0 0.16];

        
% Differential Equation
[tOut xOut] = ode15s(f, tSpan, x0);

% Create new Figure window for new plot
figure;
plot(tOut, xOut)
hold on
plot([0,tOut(end)], [xi1,xi1], '--k')
plot([0,tOut(end)], [xi2,xi2], '--r')

legend('x(t)', 'z_1', 'z_2')
