% HIV Mutation Model with immune response
clear;clc;

% Coefficients
a = 5;
b = 4;
c = 5;
g = 1;
h = 1;
k = 1;


Ndiv = c*g/(a*k - b*h)


% Initial condition, time span
y0 = [0.05; zeros(12,1)];

% Differential Equation
dy = @(t,y) [(a-b*y(13) - c*y(7))*y(1);
            (a-b*y(13) - c*y(8))*y(2);
            (a-b*y(13) - c*y(9))*y(3);
            (a-b*y(13) - c*y(10))*y(4);
            (a-b*y(13) - c*y(11))*y(5);
            (a-b*y(13) - c*y(12))*y(6);
            g*y(1) - k*y(7)*sum(y(1:6));
            g*y(2) - k*y(8)*sum(y(1:6));
            g*y(3) - k*y(9)*sum(y(1:6));
            g*y(4) - k*y(10)*sum(y(1:6));
            g*y(5) - k*y(11)*sum(y(1:6));
            g*y(6) - k*y(12)*sum(y(1:6));
            (h-k*y(13))*sum(y(1:6))];

fig1=figure('Color',[1 1 1]);
set(fig1,'defaulttextinterpreter','latex');
        
% Solve ODE up to first mutation
[t1 yOut] = ode45(dy, [0, 0.5], y0);

V = yOut(:,1:6);
S1 = sum(yOut(:, 7:12));
z1 = yOut(:, 13);
plot(t1, V)
hold on

%New "initial" data
y1 = yOut(end,:);
y1(2) = y1(2) + 1e-2;

% Solve ODE to second mutation
[t2 yOut] = ode45(dy, [0.5, 1], y1);

V = yOut(:,1:6);
S2 = sum(yOut(:, 7:12));
z2 = yOut(:, 13);
plot(t2, V)



%New "initial" data
y2 = yOut(end,:);
y2(3) = y2(3) + 1e-2;

% Solve ODE to second mutation
[t3 yOut] = ode45(dy, [1, 1.5], y2); %[1, 20]

V = yOut(:,1:6);
S3 = sum(yOut(:, 7:12));
z3 = yOut(:, 13);
plot(t3, V)



%New "initial" data
y3 = yOut(end,:);
y3(4) = y3(4) + 1e-2;

% Solve ODE to second mutation
[t4 yOut] = ode45(dy, [1.5, 2], y3);  %[1.5, 20]

V = yOut(:,1:6);
S4 = sum(yOut(:, 7:12));
z4 = yOut(:, 13);
plot(t4, V)



%New "initial" data
y4 = yOut(end,:);
y4(5) = y4(5) + 1e-2;

% Solve ODE to second mutation
[t5 yOut] = ode45(dy, [2, 2.5], y4);  %[2, 20]

V = yOut(:,1:6);
S5 = sum(yOut(:, 7:12));
z5 = yOut(:, 13);
plot(t5, V)



%New "initial" data
y5 = yOut(end,:);
y5(6) = y5(6) + 1e-2;


% Solve ODE to second mutation
[t6 yOut] = ode45(dy, [2.5, 20], y5); 

V = yOut(:,1:6);
S5 = sum(yOut(:, 7:12));
z5 = yOut(:, 13);
plot(t6, V)


legend('V_1(t)', 'V_2(t)', 'V_3(t)', 'V_4(t)', 'V_5(t)', 'V_6(t)');
xlabel('Time (yrs)');
ylabel('Strain Population');


