clear; clc;

dx = 5e-2; %1e-2
dy = dx;
dt = 1e-1*dx^2;

a = -2;
b = 2;

%Constants
alpha = 0.1;
beta = 0.25;
eta = 0.5;


T1 = alpha^2/4;
t1 = 0:dt:T1;
n1 = floor(T1/dt);

T2 = beta^2/4;
t2 = 0:dt:T2;
n2 = floor(T2/dt);

x = a:dx:b;
y = x;

u(:,:,:) = zeros(length(t1)+1,length(x),length(y));

for j = 1:length(x)
    for k = 1:length(x)
        if ((abs(x(j)) <= dx & y(k) >= -dy & y(k) <= 1) | (abs(y(k)) <= dy & x(j) >= 0 & x(j) <= 0.5))
            u(1,j,k) = 1;            
        end
    end
end


z = squeeze(u(1,:,:));
surf(x, y, z'), title('Initial Dose D(x,y)'), 
axis([a,b,a,b,0,1.5]), xlabel('x'), ylabel('y'), zlabel('D(x,y)')


for i = 1:n1
        for j = 2:length(x)-1
            for k = 2:length(y)-1
                u(i+1,j,k) = u(i,j,k)...
                    + (dt/dx^2)*(u(i,j+1,k) -2*u(i,j,k) + u(i,j-1,k))...
                    + (dt/dy^2)*(u(i,j,k+1) -2*u(i,j,k) + u(i,j,k-1));
            end
        end
end
   
w(1,:,:) = u(1,:,:);

for i = 1:n2
        for j = 2:length(x)-1
            for k = 2:length(y)-1
                w(i+1,j,k) = w(i,j,k)...
                    + (dt/dx^2)*(w(i,j+1,k) -2*w(i,j,k) + w(i,j-1,k))...
                    + (dt/dy^2)*(w(i,j,k+1) -2*w(i,j,k) + w(i,j,k-1));
            end
        end
end

z(:,:) = (1/(1+eta))*(u(n1+1,:,:) + eta*w(n2+1,:,:));

figure;
surf(x, y, z'), title('Scattered shape E(x,y)'),
axis([a,b,a,b,0,1.5]), xlabel('x'), ylabel('y'), zlabel('E(x,y)')
%,'EdgeColor', 'none'