%2-D Diffusion with Implicit Method - Direct Scattering Problem
clear;clc;

%Parameters
nx=200;                          %Number of steps in space(x)
ny=200;                          %Number of steps in space(y)       
nt=10;                           %Number of time steps 
alpha = 0.25;                    %Scattering constant
T = alpha^2/4;                   %Final time
dt=T/nt                          %Width of each time step
dx=4/(nx-1);                     %Width of space step(x)
dy=4/(ny-1);                     %Width of space step(y)
x=-2:dx:2;                       %Range of x(0,2) and specifying the grid points
y=-2:dy:2;                       %Range of y(0,2) and specifying the grid points
u=zeros(nx,ny);                  %Preallocating u
un=zeros(nx,ny);                 %Preallocating un
vis=1;                           %Diffusion coefficient/viscocity

u = zeros(nx,ny);

%Initial Conditions
for j=1:nx
    for k=1:ny
        if ((abs(x(j)) <= dx & y(k) >= -dy & y(k) <= 1) | (abs(y(k)) <= dy & x(j) >= 0 & x(j) <= 0.5))
            u(j,k) = 1;            
        end
    end
end


%B.C vector
bc=zeros(nx-2,ny-2);

%Calculating the coefficient matrix for the implicit scheme
Ex=sparse(2:nx-2,1:nx-3,1,nx-2,nx-2);
Ax=Ex+Ex'-2*speye(nx-2);       
Ey=sparse(2:ny-2,1:ny-3,1,ny-2,ny-2);
Ay=Ey+Ey'-2*speye(ny-2);        
A=kron(Ay/dy^2,speye(nx-2))+kron(speye(ny-2),Ax/dx^2);
D=speye((nx-2)*(ny-2))-vis*dt*A;

%Calculating the field variable for each time step
i=2:nx-1;
j=2:ny-1;
for it=0:nt
    un=u;
    h=surf(x,y,u','EdgeColor','none');       %plotting the field variable
    shading interp
    axis ([-2 2 -2 2 0 2])
    title({['2-D Diffusion with {\nu} = ',num2str(vis)];['time (\itt) = ',num2str(it*dt)]})
    xlabel('x \rightarrow')
    ylabel('{\leftarrow} y')
    zlabel('u(t,x,y) \rightarrow')
    drawnow; 
    refreshdata(h)
   
   
    U=un;U(1,:)=[];U(end,:)=[];U(:,1)=[];U(:,end)=[];
    U=reshape(U+bc,[],1);
    U=D\U;
    U=reshape(U,nx-2,ny-2);
    u(2:nx-1,2:ny-1)=U;
   
    %Dirichlet BCs
    u(1,:)=0;
    u(nx,:)=0;
    u(:,1)=0;
    u(:,ny)=0;
    
end