function [nVinf, nV2] = colKdVfunc(x, T, IC, method)
%clear all; clc;
% The function form of colKdV returns norm errors for a given solution and 
% inital condition defined in function. All parameters are defined in 
% function, as of now.


h = x(2)-x(1);
if(method == 1)
    dt = h^2;
elseif(method == 2)
    dt = h;
elseif(method == 3)
    dt = h;
end

tStep = T/dt+1
if(IC ==1)
%%%%%%%%%%%%%%%%%%%%%%%%%% Soliton Solution %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Assumes x is at least 0-2.
eps = 1;
mu = 5*10^(-4);
% This code implements collocation for time dependent KdV. We use implicit
% euler to time step.
% Inital condition in time: g.
c = .3;
c2 = .1;
a = .5*sqrt(eps*c/mu);
b = a*eps*c;
a2 = .5*sqrt(eps*c2/mu);
g = @(k) 3*c*(sech(a*k-6))^2;%+3*c2*(sech(a2*k-8))^2;
gT = @(k,t) 3*c*(sech(a*k-b*t-6))^2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif(IC ==2)
%%%%%%%%%%%%%%%%%%%%%%%%%% Wave Interaction %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% As of yet, unknown x.
eps = 6;
mu = 1;
g = @(k) 12*(3+4*cosh(2*k)+cosh(4*k))/((3*cosh(k)+cosh(3*k))^2);
gT = @(k,t) 12*(3+4*cosh(2*k-8*t)+cosh(4*k-64*t))/((3*cosh(k-28*t)+cosh(3*k-36*t))^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif(IC ==3)
%%%%%%%%%%%%%%%%%%%%%%%%%% Wave Interaction 2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
eps = 6;
mu = 1;
g = @(k) 5*(4.5*(csch(1.5*(k+14.5)))^2+2*(sech(k+12))^2)/((3*coth(1.5*(k+14.5))-2*tanh(k+12))^2);
gT = @(k,t) 5*(4.5*(csch(1.5*(k-9*t+14.5)))^2+2*(sech(k-4*t+12))^2)/((3*coth(1.5*(k-9*t+14.5))-2*tanh(k-4*t+12))^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Maxwellian IC %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is left out of the if statements, as we do not have a true solution.
% mu = .001 -->.7
% eps = 1;
%g = @(k) exp(-(k^2));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First we construct the basis functions
B = createBasis(x);
dB = createDBasis(x);
d3B = createD3Basis(x);

% Next we construct the necessary matrices (N-1)X(N+2) nonzero component.
% Bottom three rows await BCs.
V = createV(x,B);
V1 = eps*createV1(x,dB);
V3 = mu*createV3(x,d3B);
C1 = BC1(x,B);
C2 = BC2(x,B);
C3 = BC3(x,dB);

M = (V+C1+C2+C3);
% Find initial condition:
init = inital(x,M,g);


if(method == 1)
    aSoln = tIntegrator(x,B,V,V1,(V3+C1+C2+C3),init,dt,tStep);
elseif(method == 2)
    aSoln = crankIntegrator(x,V,V1,V3,C1,C2,C3,init,dt,tStep);
elseif(method == 3)
    aSoln = eXcrankIntegrator(x,V,V1,V3,C1,C2,C3,init,dt,tStep);
end

% Check to make sure this code function, with pictures!
createPlot(x,aSoln(:,1),B)
figure
createPlot(x,aSoln(:,end),B)

[nVinf, nV2] = compSoln(x, aSoln(:,end), B, gT, T);





end