clear;clc;
% Simulates the one-dimensional basal cell carcinoma model in x direction
% with initial conditions c(x,0) = n(x,0) = 1
% and boundary conditions dn/dx(0,t) = dc/dx(0,t) = 0
% and dn/dx(L,t) = dc/dx(L,t) = 0

dx = 0.5;
dt = 0.02;
L = 300;
T = 3;
x = 0:dx:L;
t = 0:dt:T;
I = length(x)-1;
K = length(t)-1;
sigma = 1;

n = zeros(I+1,K+1);
c = zeros(I+1,K+1);

n(:,1) = 1;
c(:,1) = 1;

for k = 1:K
    for i = 2:I
        n(i,k+1) = n(i,k) + dt/(dx^2)*(n(i+1,k) -2*n(i,k) + n(i-1,k))...
            -dt*n(i,k)*c(i,k);
        c(i,k+1) = c(i,k) + dt*sigma*n(i,k)*c(i,k)*...
            (c(i+1,k)-2*c(i,k)+c(i-1,k))/(dx^2)...
            +dt*sigma/(4*dx^2)*(n(i,k)*(c(i+1,k)-c(i-1,k))+c(i,k)...
            *(n(i+1,k)-n(i-1,k)))*(c(i+1,k)-c(i-1,k))+dt*n(i,k)*c(i,k);
    end
    n(1,k+1) = n(2,k+1);
    n(I+1,k+1) = n(I,k+1);
    c(1,k+1) = c(2,k+1);
    c(I+1,k+1) = c(I,k+1);
end

for l = 0:3
    subplot(4,2,2*l+1), plot(x,n(:,50*l+1)), xlabel('x'),...
        ylabel(['n(x,',num2str((50*l)*dt),')'])
    axis([0 300 0 1])
end

for m = 0:3
    subplot(4,2,2*(m+1)), plot(x,c(:,50*m+1)), xlabel('x'),...
        ylabel(['c(x,',num2str((50*m)*dt),')'])
    axis([0 300 0 3])
end
