clear;clc;
% Simulates the two-dimensional basal cell carcinoma model
% with initial conditions n(x,y,0) = 1 for 0<x<L and 0<y<H,
% c(x,y,0) = 1 for 0<y<5, c(x,y,0) = 0 for 5<y<H, 0<x<L,
% and boundary conditions n(x,H,t) = 1 for 0<x<L,
% dn/dx(x,y,t) = dc/dx(x,y,t) = 0 for x = 0 or L, 0<y<H,
% and dn/dy(x,0,t) = dc/dy(x,0,t) = dc/dy(x,H,t) = 0, for0<x<L.

dx = 0.5;
dy = 0.5;
dt = 0.012;
L = 300;
H = 150;
T = 1200;
x = 0:dx:L;
y = 0:dy:H;
t = 0:dt:T;
I = length(x)-1;
J = length(y)-1;
K = length(t)-1;
sigma = 1;

n = zeros(I+1,J+1,2);
c = zeros(I+1,J+1,2);

n(:,:,1) = 1;

M = find(y>=0 & y<=5);
c(:,M,1) = 1;

k=1;
for q = 1:K
    for i = 2:I
        for j = 2:J
        n(i,j,k+1)=n(i,j,k)+dt/(dx^2)*(n(i+1,j,k)-2*n(i,j,k)+n(i-1,j,k))...
            +dt/(dy^2)*(n(i,j+1,k)-2*n(i,j,k)+n(i,j-1,k))...
            -dt*n(i,j,k)*c(i,j,k);
        c(i,j,k+1)=c(i,j,k)+dt*sigma*n(i,j,k)*c(i,j,k)*...
            (c(i+1,j,k)-2*c(i,j,k)+c(i-1,j,k))/(dx^2)...
            +dt*sigma/(4*dx^2)*(n(i,j,k)*(c(i+1,j,k)-c(i-1,j,k))+c(i,j,k)...
            *(n(i+1,j,k)-n(i-1,j,k)))*(c(i+1,j,k)-c(i-1,j,k))...
            + dt*sigma*n(i,j,k)*c(i,j,k)*(c(i,j+1,k)-2*c(i,j,k)+c(i,j-1,k))...
            /(dy^2)+dt*sigma/(4*dy^2)*(n(i,j,k)*(c(i,j+1,k)-c(i,j-1,k))...
            +c(i,j,k)*(n(i,j+1,k)-n(i,j-1,k)))*(c(i,j+1,k)-c(i,j-1,k))...
            +dt*n(i,j,k)*c(i,j,k);
        end
    end
    n(2:I,1,k+1) = n(2:I,2,k+1);
    n(:,J+1,k+1) = 1;
    n(1,1:J,k+1) = n(2,1:J,k+1);
    n(I+1,1:J,k+1) = n(I,1:J,k+1);
    c(2:I,1,k+1) = c(2:I,2,k+1);
    c(2:I,J+1,k+1) = c(2:I,J,k+1);
    c(1,:,k+1) = c(2,:,k+1);
    c(I+1,:,k+1) = c(I,:,k+1);
    
    n(:,:,1) = n(:,:,2);
    c(:,:,1) = c(:,:,2);
end

subplot(1,2,1), surf(x,y,n(:,:,2)','edgecolor','none')
title('Nutrient Concentration')
xlabel('x'), ylabel('y'), zlabel('n(1200)')

subplot(1,2,2), surf(x,y,c(:,:,2)','edgecolor','none')
xlabel('x'), ylabel('y'), zlabel('c(1200)')
title('Tumor Cell Density')
