clear;clc;
% Simulates the one-dimensional basal cell carcinoma model in y direction
% with initial conditions c(y,0) = 1 for 0<y<5, c(y,o) = 0 for 5<y<H,
% and n(y,0) = 1 for 0<y<H,
% and boundary conditions n(H,t) = 1,
% dn/dy(0,t) = dc/dy(0,t) = dc/dy(H,t) = 0.

dy = 0.5;
dt = 0.02;
H = 150;
T = 6000;
y = 0:dy:H;
t = 0:dt:T;
J = length(y)-1;
K = length(t)-1;
sigma = 1;

n = zeros(J+1,K+1);
c = zeros(J+1,K+1);

n(:,1) = 1;
n(J+1,:) = 1;

I = find(y>=0 & y<=5);
c(I,1) = 1;

for k = 1:K
    for j = 2:J
        n(j,k+1) = n(j,k) + dt/(dy^2)*(n(j+1,k) -2*n(j,k) + n(j-1,k))...
            -dt*n(j,k)*c(j,k);
        c(j,k+1) = c(j,k) + dt*sigma*n(j,k)*c(j,k)*...
            (c(j+1,k)-2*c(j,k)+c(j-1,k))/(dy^2)...
            +dt*sigma/(4*dy^2)*(n(j,k)*(c(j+1,k)-c(j-1,k))+c(j,k)...
            *(n(j+1,k)-n(j-1,k)))*(c(j+1,k)-c(j-1,k))+dt*n(j,k)*c(j,k);
    end
    n(1,k+1) = n(2,k+1);
    n(I+1,k+1) = n(I,k+1);
    c(1,k+1) = c(2,k+1);
    c(I+1,k+1) = c(I,k+1);
end

for l = 0:3
    subplot(4,2,2*l+1), plot(y,n(:,100000*l+1)), xlabel('y'),...
        ylabel(['n(y,',num2str((100000*l)*dt),')'])
    axis([0 150 0 1])
end

for m = 0:3
    subplot(4,2,2*(m+1)), plot(y,c(:,100000*m+1)), xlabel('y'),...
        ylabel(['c(y,',num2str((100000*m)*dt),')'])
    axis([0 150 0 5])
end
